@@ -61,16 +61,19 @@ class Dependency(Parameter):
 
 
 class Argument(Parameter):
-    def __init__(self):
+    def __init__(self, has_default, default=None):
         self._ordering = _param_counter.next()
+        self._has_default = has_default
+        self._default = default
 
 
 def dependency(key):
     return Dependency(key, {})
 
 
-def argument():
-    return Argument()
+def argument(**kwargs):
+    kwargs["has_default"] = "default" in kwargs
+    return Argument(**kwargs)
 
 
 class InjectableConstructor(object):
@@ -95,8 +98,12 @@ class Base(object):
                     arg_name = _key_to_arg_name(key)
                     if arg_name in extra_args:
                         setattr(self, key, extra_args.pop(arg_name))
+                    elif attr._has_default:
+                        setattr(self, key, attr._default)
                     else:
                         raise _missing_keyword_argument_error(arg_name)
+                        
+            _check_keyword_arguments_consumed(extra_args)
         else:
             if len(args) > len(attrs):
                 raise TypeError(
@@ -116,8 +123,7 @@ class Base(object):
                 else:
                     raise _missing_keyword_argument_error(arg_name)
         
-        if len(kwargs) > 0:
-            raise TypeError("Unexpected keyword argument: " + kwargs.items()[0][0])
+        _check_keyword_arguments_consumed(kwargs)
     
     __init__.zuice = InjectableConstructor()
 
@@ -128,3 +134,13 @@ def _key_to_arg_name(key):
 
 def _missing_keyword_argument_error(key):
     return TypeError("Missing keyword argument: %s" % key)
+
+
+def _unexpected_keyword_argument_error(key):
+    raise TypeError("Unexpected keyword argument: " + key)
+
+
+def _check_keyword_arguments_consumed(kwargs):
+    if len(kwargs) > 0:
+        raise _unexpected_keyword_argument_error(kwargs.keys()[0])
+    
